/* tslint:disable */
/* eslint-disable */
/**
* Read a Parquet file into Arrow data using the [`arrow`](https://crates.io/crates/arrow) and
* [`parquet`](https://crates.io/crates/parquet) Rust crates.
*
* Example:
*
* ```js
* import { tableFromIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { readParquet } from "parquet-wasm/node";
*
* const resp = await fetch("https://example.com/file.parquet");
* const parquetUint8Array = new Uint8Array(await resp.arrayBuffer());
* const arrowUint8Array = readParquet(parquetUint8Array);
* const arrowTable = tableFromIPC(arrowUint8Array);
* ```
*
* @param parquet_file Uint8Array containing Parquet data
* @returns Uint8Array containing Arrow data in [IPC Stream format](https://arrow.apache.org/docs/format/Columnar.html#ipc-streaming-format). To parse this into an Arrow table, pass to `tableFromIPC` in the Arrow JS bindings.
* @param {Uint8Array} parquet_file
* @returns {Uint8Array}
*/
export function readParquet(parquet_file: Uint8Array): Uint8Array;
/**
* Write Arrow data to a Parquet file using the [`arrow`](https://crates.io/crates/arrow) and
* [`parquet`](https://crates.io/crates/parquet) Rust crates.
*
* For example, to create a Parquet file with Snappy compression:
*
* ```js
* import { tableToIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { WriterPropertiesBuilder, Compression, writeParquet } from "parquet-wasm/node";
*
* // Given an existing arrow table under `table`
* const arrowUint8Array = tableToIPC(table, "file");
* const writerProperties = new WriterPropertiesBuilder()
*   .setCompression(Compression.SNAPPY)
*   .build();
* const parquetUint8Array = writeParquet(arrowUint8Array, writerProperties);
* ```
*
* If `writerProperties` is not provided or is `null`, the default writer properties will be used.
* This is equivalent to `new WriterPropertiesBuilder().build()`.
*
* @param arrow_file Uint8Array containing Arrow data in [IPC Stream format](https://arrow.apache.org/docs/format/Columnar.html#ipc-streaming-format). If you have an Arrow table in JS, call `tableToIPC(table)` in the JS bindings and pass the result here.
* @param writer_properties Configuration for writing to Parquet. Use the {@linkcode WriterPropertiesBuilder} to build a writing configuration, then call `.build()` to create an immutable writer properties to pass in here.
* @returns Uint8Array containing written Parquet data.
* @param {Uint8Array} arrow_file
* @param {WriterProperties | undefined} writer_properties
* @returns {Uint8Array}
*/
export function writeParquet(arrow_file: Uint8Array, writer_properties?: WriterProperties): Uint8Array;
/**
* Supported compression algorithms.
*
* Codecs added in format version X.Y can be read by readers based on X.Y and later.
* Codec support may vary between readers based on the format version and
* libraries available at runtime.
*/
export enum Compression {
  UNCOMPRESSED,
  SNAPPY,
  GZIP,
  BROTLI,
/**
* @deprecated as of Parquet 2.9.0.
* Switch to LZ4_RAW
*/
  LZ4,
  ZSTD,
  LZ4_RAW,
}
/**
* Encodings supported by Parquet.
* Not all encodings are valid for all types. These enums are also used to specify the
* encoding of definition and repetition levels.
*/
export enum Encoding {
/**
* Default byte encoding.
* - BOOLEAN - 1 bit per value, 0 is false; 1 is true.
* - INT32 - 4 bytes per value, stored as little-endian.
* - INT64 - 8 bytes per value, stored as little-endian.
* - FLOAT - 4 bytes per value, stored as little-endian.
* - DOUBLE - 8 bytes per value, stored as little-endian.
* - BYTE_ARRAY - 4 byte length stored as little endian, followed by bytes.
* - FIXED_LEN_BYTE_ARRAY - just the bytes are stored.
*/
  PLAIN,
/**
* **Deprecated** dictionary encoding.
*
* The values in the dictionary are encoded using PLAIN encoding.
* Since it is deprecated, RLE_DICTIONARY encoding is used for a data page, and
* PLAIN encoding is used for dictionary page.
*/
  PLAIN_DICTIONARY,
/**
* Group packed run length encoding.
*
* Usable for definition/repetition levels encoding and boolean values.
*/
  RLE,
/**
* Bit packed encoding.
*
* This can only be used if the data has a known max width.
* Usable for definition/repetition levels encoding.
*/
  BIT_PACKED,
/**
* Delta encoding for integers, either INT32 or INT64.
*
* Works best on sorted data.
*/
  DELTA_BINARY_PACKED,
/**
* Encoding for byte arrays to separate the length values and the data.
*
* The lengths are encoded using DELTA_BINARY_PACKED encoding.
*/
  DELTA_LENGTH_BYTE_ARRAY,
/**
* Incremental encoding for byte arrays.
*
* Prefix lengths are encoded using DELTA_BINARY_PACKED encoding.
* Suffixes are stored using DELTA_LENGTH_BYTE_ARRAY encoding.
*/
  DELTA_BYTE_ARRAY,
/**
* Dictionary encoding.
*
* The ids are encoded using the RLE encoding.
*/
  RLE_DICTIONARY,
/**
* Encoding for floating-point data.
*
* K byte-streams are created where K is the size in bytes of the data type.
* The individual bytes of an FP value are scattered to the corresponding stream and
* the streams are concatenated.
* This itself does not reduce the size of the data but can lead to better compression
* afterwards.
*/
  BYTE_STREAM_SPLIT,
}
/**
* The Parquet version to use when writing
*/
export enum WriterVersion {
  V1,
  V2,
}
/**
* Controls the level of statistics to be computed by the writer
*/
export enum EnabledStatistics {
/**
* Compute no statistics
*/
  None,
/**
* Compute chunk-level statistics but not page-level
*/
  Chunk,
/**
* Compute page-level and chunk-level statistics
*/
  Page,
}
/**
* Immutable struct to hold writing configuration for `writeParquet`.
*
* Use {@linkcode WriterPropertiesBuilder} to create a configuration, then call {@linkcode
* WriterPropertiesBuilder.build} to create an instance of `WriterProperties`.
*/
export class WriterProperties {
  free(): void;
}
/**
* Builder to create a writing configuration for `writeParquet`
*
* Call {@linkcode build} on the finished builder to create an immputable {@linkcode WriterProperties} to pass to `writeParquet`
*/
export class WriterPropertiesBuilder {
  free(): void;
/**
* Returns default state of the builder.
*/
  constructor();
/**
* Finalizes the configuration and returns immutable writer properties struct.
* @returns {WriterProperties}
*/
  build(): WriterProperties;
/**
* Sets writer version.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setWriterVersion(value: number): WriterPropertiesBuilder;
/**
* Sets data page size limit.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setDataPagesizeLimit(value: number): WriterPropertiesBuilder;
/**
* Sets dictionary page size limit.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setDictionaryPagesizeLimit(value: number): WriterPropertiesBuilder;
/**
* Sets write batch size.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setWriteBatchSize(value: number): WriterPropertiesBuilder;
/**
* Sets maximum number of rows in a row group.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setMaxRowGroupSize(value: number): WriterPropertiesBuilder;
/**
* Sets "created by" property.
* @param {string} value
* @returns {WriterPropertiesBuilder}
*/
  setCreatedBy(value: string): WriterPropertiesBuilder;
/**
* Sets encoding for any column.
*
* If dictionary is not enabled, this is treated as a primary encoding for all
* columns. In case when dictionary is enabled for any column, this value is
* considered to be a fallback encoding for that column.
*
* Panics if user tries to set dictionary encoding here, regardless of dictionary
* encoding flag being set.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setEncoding(value: number): WriterPropertiesBuilder;
/**
* Sets compression codec for any column.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setCompression(value: number): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable dictionary encoding for any column.
*
* Use this method to set dictionary encoding, instead of explicitly specifying
* encoding in `set_encoding` method.
* @param {boolean} value
* @returns {WriterPropertiesBuilder}
*/
  setDictionaryEnabled(value: boolean): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable statistics for any column.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setStatisticsEnabled(value: number): WriterPropertiesBuilder;
/**
* Sets max statistics size for any column.
* Applicable only if statistics are enabled.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setMaxStatisticsSize(value: number): WriterPropertiesBuilder;
/**
* Sets encoding for a column.
* Takes precedence over globally defined settings.
*
* If dictionary is not enabled, this is treated as a primary encoding for this
* column. In case when dictionary is enabled for this column, either through
* global defaults or explicitly, this value is considered to be a fallback
* encoding for this column.
*
* Panics if user tries to set dictionary encoding here, regardless of dictionary
* encoding flag being set.
* @param {string} col
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnEncoding(col: string, value: number): WriterPropertiesBuilder;
/**
* Sets compression codec for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnCompression(col: string, value: number): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable dictionary encoding for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {boolean} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnDictionaryEnabled(col: string, value: boolean): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable statistics for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnStatisticsEnabled(col: string, value: number): WriterPropertiesBuilder;
/**
* Sets max size for statistics for a column.
* Takes precedence over globally defined settings.
* @param {string} col
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setColumnMaxStatisticsSize(col: string, value: number): WriterPropertiesBuilder;
}

export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly readParquet: (a: number, b: number, c: number) => void;
  readonly writeParquet: (a: number, b: number, c: number, d: number) => void;
  readonly __wbg_writerproperties_free: (a: number) => void;
  readonly __wbg_writerpropertiesbuilder_free: (a: number) => void;
  readonly writerpropertiesbuilder_new: () => number;
  readonly writerpropertiesbuilder_build: (a: number) => number;
  readonly writerpropertiesbuilder_setWriterVersion: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDataPagesizeLimit: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDictionaryPagesizeLimit: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setWriteBatchSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setMaxRowGroupSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setCreatedBy: (a: number, b: number, c: number) => number;
  readonly writerpropertiesbuilder_setEncoding: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setCompression: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setDictionaryEnabled: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setStatisticsEnabled: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setMaxStatisticsSize: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setColumnEncoding: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnCompression: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnDictionaryEnabled: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnStatisticsEnabled: (a: number, b: number, c: number, d: number) => number;
  readonly writerpropertiesbuilder_setColumnMaxStatisticsSize: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_endStream: (a: number, b: number) => number;
  readonly ZSTD_compressStream: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompressStream: (a: number, b: number, c: number) => number;
  readonly ZSTD_compress2: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_decompressDCtx: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_isError: (a: number) => number;
  readonly ZSTD_versionNumber: () => number;
  readonly ZSTD_versionString: () => number;
  readonly ZSTD_minCLevel: () => number;
  readonly ZSTD_maxCLevel: () => number;
  readonly ZSTD_getDecompressedSize: (a: number, b: number) => number;
  readonly ZSTD_compressBound: (a: number) => number;
  readonly ZSTD_createCCtx: () => number;
  readonly ZSTD_initCStream: (a: number, b: number) => number;
  readonly ZSTD_CCtx_loadDictionary: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_refCDict: (a: number, b: number) => number;
  readonly ZSTD_CCtx_refPrefix: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_CCtx: (a: number) => number;
  readonly ZSTD_CCtx_reset: (a: number, b: number) => number;
  readonly ZSTD_CCtx_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_setPledgedSrcSize: (a: number, b: number) => number;
  readonly ZSTD_CStreamInSize: () => number;
  readonly ZSTD_CStreamOutSize: () => number;
  readonly ZSTD_freeCCtx: (a: number) => number;
  readonly ZSTD_getErrorName: (a: number) => number;
  readonly ZSTD_createDCtx: () => number;
  readonly ZSTD_initDStream: (a: number) => number;
  readonly ZSTD_DCtx_reset: (a: number, b: number) => number;
  readonly ZSTD_DCtx_loadDictionary: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_refDDict: (a: number, b: number) => number;
  readonly ZSTD_DCtx_refPrefix: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_DStreamInSize: () => number;
  readonly ZSTD_DStreamOutSize: () => number;
  readonly ZSTD_sizeof_DCtx: (a: number) => number;
  readonly ZSTD_freeDCtx: (a: number) => number;
  readonly ZSTD_createCDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_CDict: (a: number) => number;
  readonly ZSTD_getDictID_fromCDict: (a: number) => number;
  readonly ZSTD_freeCDict: (a: number) => number;
  readonly ZSTD_createDDict: (a: number, b: number) => number;
  readonly ZSTD_sizeof_DDict: (a: number) => number;
  readonly ZSTD_getDictID_fromDDict: (a: number) => number;
  readonly ZSTD_freeDDict: (a: number) => number;
  readonly ZSTD_compress_usingCDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_decompress_usingDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_compress_usingDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_decompress_usingDDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_compressCCtx: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_findFrameCompressedSize: (a: number, b: number) => number;
  readonly ZSTD_getFrameContentSize: (a: number, b: number) => number;
  readonly ZSTD_getDictID_fromDict: (a: number, b: number) => number;
  readonly ZSTD_getDictID_fromFrame: (a: number, b: number) => number;
  readonly rust_zstd_wasm_shim_malloc: (a: number) => number;
  readonly rust_zstd_wasm_shim_calloc: (a: number, b: number) => number;
  readonly rust_zstd_wasm_shim_free: (a: number) => void;
  readonly rust_zstd_wasm_shim_memcpy: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memmove: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memset: (a: number, b: number, c: number) => number;
  readonly ZSTD_createCCtx_advanced: (a: number) => number;
  readonly ZSTD_initStaticCCtx: (a: number, b: number) => number;
  readonly ZSTD_sizeof_CStream: (a: number) => number;
  readonly ZSTD_createCCtxParams: () => number;
  readonly ZSTD_freeCCtxParams: (a: number) => number;
  readonly ZSTD_CCtxParams_reset: (a: number) => number;
  readonly ZSTD_CCtxParams_init: (a: number, b: number) => number;
  readonly ZSTD_CCtxParams_init_advanced: (a: number, b: number) => number;
  readonly ZSTD_checkCParams: (a: number) => number;
  readonly ZSTD_cParam_getBounds: (a: number, b: number) => void;
  readonly ZSTD_CCtxParams_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtxParams_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_setParametersUsingCCtxParams: (a: number, b: number) => number;
  readonly ZSTD_CCtx_loadDictionary_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_CCtx_loadDictionary_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_refThreadPool: (a: number, b: number) => number;
  readonly ZSTD_CCtx_refPrefix_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_adjustCParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_estimateCCtxSize_usingCCtxParams: (a: number) => number;
  readonly ZSTD_estimateCCtxSize_usingCParams: (a: number) => number;
  readonly ZSTD_estimateCCtxSize: (a: number) => number;
  readonly ZSTD_estimateCStreamSize_usingCCtxParams: (a: number) => number;
  readonly ZSTD_estimateCStreamSize_usingCParams: (a: number) => number;
  readonly ZSTD_estimateCStreamSize: (a: number) => number;
  readonly ZSTD_getFrameProgression: (a: number, b: number) => void;
  readonly ZSTD_toFlushNow: (a: number) => number;
  readonly ZSTD_copyCCtx: (a: number, b: number, c: number) => number;
  readonly ZSTD_generateSequences: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressStream2: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_mergeBlockDelimiters: (a: number, b: number) => number;
  readonly ZSTD_writeSkippableFrame: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressContinue: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_getBlockSize: (a: number) => number;
  readonly ZSTD_compressBlock: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressBegin_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressBegin_usingDict: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_compressBegin: (a: number, b: number) => number;
  readonly ZSTD_compressEnd: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compress_advanced: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_compress: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_estimateCDictSize_advanced: (a: number, b: number, c: number) => number;
  readonly ZSTD_estimateCDictSize: (a: number, b: number) => number;
  readonly ZSTD_createCDict_advanced: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_createCDict_advanced2: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_createCDict_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_initStaticCDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_compressBegin_usingCDict_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_compressBegin_usingCDict: (a: number, b: number) => number;
  readonly ZSTD_compress_usingCDict_advanced: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_createCStream: () => number;
  readonly ZSTD_createCStream_advanced: (a: number) => number;
  readonly ZSTD_initStaticCStream: (a: number, b: number) => number;
  readonly ZSTD_freeCStream: (a: number) => number;
  readonly ZSTD_resetCStream: (a: number, b: number) => number;
  readonly ZSTD_initCStream_usingCDict_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initCStream_usingCDict: (a: number, b: number) => number;
  readonly ZSTD_initCStream_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_initCStream_usingDict: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initCStream_srcSize: (a: number, b: number, c: number) => number;
  readonly ZSTD_compressStream2_simpleArgs: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_compressSequences: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_flushStream: (a: number, b: number) => number;
  readonly ZSTD_defaultCLevel: () => number;
  readonly ZSTD_getCParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_getParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_createDDict_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_createDDict_byReference: (a: number, b: number) => number;
  readonly ZSTD_initStaticDDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_estimateDDictSize: (a: number, b: number) => number;
  readonly ZSTD_estimateDCtxSize: () => number;
  readonly ZSTD_initStaticDCtx: (a: number, b: number) => number;
  readonly ZSTD_createDCtx_advanced: (a: number) => number;
  readonly ZSTD_copyDCtx: (a: number, b: number) => void;
  readonly ZSTD_isFrame: (a: number, b: number) => number;
  readonly ZSTD_isSkippableFrame: (a: number, b: number) => number;
  readonly ZSTD_frameHeaderSize: (a: number, b: number) => number;
  readonly ZSTD_getFrameHeader_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_getFrameHeader: (a: number, b: number, c: number) => number;
  readonly ZSTD_readSkippableFrame: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_findDecompressedSize: (a: number, b: number) => number;
  readonly ZSTD_decompressBound: (a: number, b: number) => number;
  readonly ZSTD_insertBlock: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompressBegin_usingDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompress: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_nextSrcSizeToDecompress: (a: number) => number;
  readonly ZSTD_nextInputType: (a: number) => number;
  readonly ZSTD_decompressContinue: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_decompressBegin: (a: number) => number;
  readonly ZSTD_decompressBegin_usingDDict: (a: number, b: number) => number;
  readonly ZSTD_createDStream: () => number;
  readonly ZSTD_initStaticDStream: (a: number, b: number) => number;
  readonly ZSTD_createDStream_advanced: (a: number) => number;
  readonly ZSTD_freeDStream: (a: number) => number;
  readonly ZSTD_DCtx_loadDictionary_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_DCtx_loadDictionary_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_refPrefix_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initDStream_usingDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_initDStream_usingDDict: (a: number, b: number) => number;
  readonly ZSTD_resetDStream: (a: number) => number;
  readonly ZSTD_DCtx_setMaxWindowSize: (a: number, b: number) => number;
  readonly ZSTD_dParam_getBounds: (a: number, b: number) => void;
  readonly ZSTD_DCtx_setFormat: (a: number, b: number) => number;
  readonly ZSTD_DCtx_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_DStream: (a: number) => number;
  readonly ZSTD_decodingBufferSize_min: (a: number, b: number) => number;
  readonly ZSTD_estimateDStreamSize: (a: number) => number;
  readonly ZSTD_estimateDStreamSize_fromFrame: (a: number, b: number) => number;
  readonly ZSTD_decompressStream_simpleArgs: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_decompressBlock: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BrotliDecoderCreateInstance: (a: number, b: number, c: number) => number;
  readonly BrotliDecoderSetParameter: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDecompressPrealloc: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number) => void;
  readonly BrotliDecoderDecompressWithReturnInfo: (a: number, b: number, c: number, d: number, e: number) => void;
  readonly BrotliDecoderDecompress: (a: number, b: number, c: number, d: number) => number;
  readonly BrotliDecoderDecompressStream: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly BrotliDecoderDecompressStreaming: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BrotliDecoderMallocU8: (a: number, b: number) => number;
  readonly BrotliDecoderFreeU8: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderMallocUsize: (a: number, b: number) => number;
  readonly BrotliDecoderFreeUsize: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDestroyInstance: (a: number) => void;
  readonly BrotliDecoderHasMoreOutput: (a: number) => number;
  readonly BrotliDecoderTakeOutput: (a: number, b: number) => number;
  readonly BrotliDecoderIsUsed: (a: number) => number;
  readonly BrotliDecoderIsFinished: (a: number) => number;
  readonly BrotliDecoderGetErrorCode: (a: number) => number;
  readonly BrotliDecoderGetErrorString: (a: number) => number;
  readonly BrotliDecoderErrorString: (a: number) => number;
  readonly BrotliDecoderVersion: () => number;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_malloc: (a: number) => number;
  readonly __wbindgen_realloc: (a: number, b: number, c: number) => number;
}

/**
* Synchronously compiles the given `bytes` and instantiates the WebAssembly module.
*
* @param {BufferSource} bytes
*
* @returns {InitOutput}
*/
export function initSync(bytes: BufferSource): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
