/* tslint:disable */
/* eslint-disable */
/**
* Read a Parquet file into Arrow data using the [`arrow2`](https://crates.io/crates/arrow2) and
* [`parquet2`](https://crates.io/crates/parquet2) Rust crates.
*
* Example:
*
* ```js
* import { tableFromIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { readParquet } from "parquet-wasm/node2";
*
* const resp = await fetch("https://example.com/file.parquet");
* const parquetUint8Array = new Uint8Array(await resp.arrayBuffer());
* const arrowUint8Array = readParquet(parquetUint8Array);
* const arrowTable = tableFromIPC(arrowUint8Array);
* ```
*
* @param parquet_file Uint8Array containing Parquet data
* @returns Uint8Array containing Arrow data in [IPC Stream format](https://arrow.apache.org/docs/format/Columnar.html#ipc-streaming-format). To parse this into an Arrow table, pass to `tableFromIPC` in the Arrow JS bindings.
* @param {Uint8Array} parquet_file
* @returns {Uint8Array}
*/
export function readParquet(parquet_file: Uint8Array): Uint8Array;
/**
* Read metadata from a Parquet file using the [`arrow2`](https://crates.io/crates/arrow2) and
* [`parquet2`](https://crates.io/crates/parquet2) Rust crates.
*
* Example:
*
* ```js
* // Edit the `parquet-wasm` import as necessary
* import { readMetadata } from "parquet-wasm/node2";
*
* const resp = await fetch("https://example.com/file.parquet");
* const parquetUint8Array = new Uint8Array(await resp.arrayBuffer());
* const parquetFileMetaData = readMetadata(parquetUint8Array);
* ```
*
* @param parquet_file Uint8Array containing Parquet data
* @returns a {@linkcode FileMetaData} object containing metadata of the Parquet file.
* @param {Uint8Array} parquet_file
* @returns {FileMetaData}
*/
export function readMetadata(parquet_file: Uint8Array): FileMetaData;
/**
* Read a single row group from a Parquet file into Arrow data using the
* [`arrow2`](https://crates.io/crates/arrow2) and [`parquet2`](https://crates.io/crates/parquet2)
* Rust crates.
*
* Example:
*
* ```js
* import { tableFromIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { readRowGroup, readMetadata } from "parquet-wasm/node2";
*
* const resp = await fetch("https://example.com/file.parquet");
* const parquetUint8Array = new Uint8Array(await resp.arrayBuffer());
* const parquetFileMetaData = readMetadata(parquetUint8Array);
*
* // Read only the first row group
* const arrowIpcBuffer = wasm.readRowGroup(parquetUint8Array, parquetFileMetaData, 0);
* const arrowTable = tableFromIPC(arrowUint8Array);
* ```
*
* Note that you can get the number of row groups in a Parquet file using {@linkcode FileMetaData.numRowGroups}
*
* @param parquet_file Uint8Array containing Parquet data
* @param meta {@linkcode FileMetaData} from a call to {@linkcode readMetadata}
* @param i Number index of the row group to parse
* @returns Uint8Array containing Arrow data in [IPC Stream format](https://arrow.apache.org/docs/format/Columnar.html#ipc-streaming-format). To parse this into an Arrow table, pass to `tableFromIPC` in the Arrow JS bindings.
* @param {Uint8Array} parquet_file
* @param {FileMetaData} meta
* @param {number} i
* @returns {Uint8Array}
*/
export function readRowGroup(parquet_file: Uint8Array, meta: FileMetaData, i: number): Uint8Array;
/**
* Asynchronously read metadata from a Parquet file using the
* [`arrow2`](https://crates.io/crates/arrow2) and [`parquet2`](https://crates.io/crates/parquet2)
* Rust crates.
*
* For now, this requires knowing the content length of the file, but hopefully this will be
* relaxed in the future.
*
* Example:
*
* ```js
* // Edit the `parquet-wasm` import as necessary
* import { readMetadataAsync } from "parquet-wasm";
*
* const url = "https://example.com/file.parquet";
* const headResp = await fetch(url, {method: 'HEAD'});
* const length = parseInt(headResp.headers.get('Content-Length'));
*
* const parquetFileMetaData = await readMetadataAsync(url, length);
* ```
*
* @param url String location of remote Parquet file containing Parquet data
* @param content_length Number content length of file in bytes
* @returns a {@linkcode FileMetaData} object containing metadata of the Parquet file.
* @param {string} url
* @param {number} content_length
* @returns {Promise<FileMetaData>}
*/
export function readMetadataAsync(url: string, content_length: number): Promise<FileMetaData>;
/**
* Asynchronously read a single row group from a Parquet file into Arrow data using the
* [`arrow2`](https://crates.io/crates/arrow2) and [`parquet2`](https://crates.io/crates/parquet2)
* Rust crates.
*
* Example:
*
* ```js
* import { tableFromIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { readRowGroupAsync, readMetadataAsync } from "parquet-wasm";
*
* const url = "https://example.com/file.parquet";
* const headResp = await fetch(url, {method: 'HEAD'});
* const length = parseInt(headResp.headers.get('Content-Length'));
*
* const parquetFileMetaData = await readMetadataAsync(url, length);
*
* // Read all batches from the file in parallel
* const promises = [];
* for (let i = 0; i < parquetFileMetaData.numRowGroups(); i++) {
*   // IMPORTANT: For now, calling `copy()` on the metadata object is required whenever passing in to
*   // a function. Hopefully this can be resolved in the future sometime
*   const rowGroupPromise = wasm.readRowGroupAsync2(url, length, parquetFileMetaData.copy(), i);
*   promises.push(rowGroupPromise);
* }
*
* const recordBatchChunks = await Promise.all(promises);
* const table = new arrow.Table(recordBatchChunks);
* ```
*
* Note that you can get the number of row groups in a Parquet file using {@linkcode FileMetaData.numRowGroups}
*
* @param url String location of remote Parquet file containing Parquet data
* @param content_length Number content length of file in bytes
* @param meta {@linkcode FileMetaData} from a call to {@linkcode readMetadata}
* @param i Number index of the row group to load
* @returns Uint8Array containing Arrow data in [IPC Stream format](https://arrow.apache.org/docs/format/Columnar.html#ipc-streaming-format). To parse this into an Arrow table, pass to `tableFromIPC` in the Arrow JS bindings.
* @param {string} url
* @param {RowGroupMetaData} row_group_meta
* @param {ArrowSchema} arrow_schema
* @returns {Promise<Uint8Array>}
*/
export function readRowGroupAsync(url: string, row_group_meta: RowGroupMetaData, arrow_schema: ArrowSchema): Promise<Uint8Array>;
/**
* Write Arrow data to a Parquet file using the [`arrow2`](https://crates.io/crates/arrow2) and
* [`parquet2`](https://crates.io/crates/parquet2) Rust crates.
*
* For example, to create a Parquet file with Snappy compression:
*
* ```js
* import { tableToIPC } from "apache-arrow";
* // Edit the `parquet-wasm` import as necessary
* import { WriterPropertiesBuilder, Compression, writeParquet } from "parquet-wasm/node2";
*
* // Given an existing arrow table under `table`
* const arrowUint8Array = tableToIPC(table, "file");
* const writerProperties = new WriterPropertiesBuilder()
*   .setCompression(Compression.SNAPPY)
*   .build();
* const parquetUint8Array = writeParquet(arrowUint8Array, writerProperties);
* ```
*
* If `writerProperties` is not provided or is `null`, the default writer properties will be used.
* This is equivalent to `new WriterPropertiesBuilder().build()`.
*
* @param arrow_file Uint8Array containing Arrow data in [IPC **File** format](https://arrow.apache.org/docs/format/Columnar.html#ipc-file-format). If you have an Arrow table in JS, call `tableToIPC(table, "file")` in the JS bindings and pass the result here.
* @param writer_properties Configuration for writing to Parquet. Use the {@linkcode WriterPropertiesBuilder} to build a writing configuration, then call `.build()` to create an immutable writer properties to pass in here.
* @returns Uint8Array containing written Parquet data.
* @param {Uint8Array} arrow_file
* @param {WriterProperties | undefined} writer_properties
* @returns {Uint8Array}
*/
export function writeParquet(arrow_file: Uint8Array, writer_properties?: WriterProperties): Uint8Array;
/**
* Supported compression algorithms.
*
* Codecs added in format version X.Y can be read by readers based on X.Y and later.
* Codec support may vary between readers based on the format version and
* libraries available at runtime.
*/
export enum Compression {
  UNCOMPRESSED,
  SNAPPY,
  GZIP,
  BROTLI,
/**
* @deprecated as of Parquet 2.9.0.
* Switch to LZ4_RAW
*/
  LZ4,
  ZSTD,
  LZ4_RAW,
}
/**
* Encodings supported by Parquet.
* Not all encodings are valid for all types. These enums are also used to specify the
* encoding of definition and repetition levels.
*/
export enum Encoding {
/**
* Default byte encoding.
* - BOOLEAN - 1 bit per value, 0 is false; 1 is true.
* - INT32 - 4 bytes per value, stored as little-endian.
* - INT64 - 8 bytes per value, stored as little-endian.
* - FLOAT - 4 bytes per value, stored as little-endian.
* - DOUBLE - 8 bytes per value, stored as little-endian.
* - BYTE_ARRAY - 4 byte length stored as little endian, followed by bytes.
* - FIXED_LEN_BYTE_ARRAY - just the bytes are stored.
*/
  PLAIN,
/**
* **Deprecated** dictionary encoding.
*
* The values in the dictionary are encoded using PLAIN encoding.
* Since it is deprecated, RLE_DICTIONARY encoding is used for a data page, and
* PLAIN encoding is used for dictionary page.
*/
  PLAIN_DICTIONARY,
/**
* Group packed run length encoding.
*
* Usable for definition/repetition levels encoding and boolean values.
*/
  RLE,
/**
* Bit packed encoding.
*
* This can only be used if the data has a known max width.
* Usable for definition/repetition levels encoding.
*/
  BIT_PACKED,
/**
* Delta encoding for integers, either INT32 or INT64.
*
* Works best on sorted data.
*/
  DELTA_BINARY_PACKED,
/**
* Encoding for byte arrays to separate the length values and the data.
*
* The lengths are encoded using DELTA_BINARY_PACKED encoding.
*/
  DELTA_LENGTH_BYTE_ARRAY,
/**
* Incremental encoding for byte arrays.
*
* Prefix lengths are encoded using DELTA_BINARY_PACKED encoding.
* Suffixes are stored using DELTA_LENGTH_BYTE_ARRAY encoding.
*/
  DELTA_BYTE_ARRAY,
/**
* Dictionary encoding.
*
* The ids are encoded using the RLE encoding.
*/
  RLE_DICTIONARY,
/**
* Encoding for floating-point data.
*
* K byte-streams are created where K is the size in bytes of the data type.
* The individual bytes of an FP value are scattered to the corresponding stream and
* the streams are concatenated.
* This itself does not reduce the size of the data but can lead to better compression
* afterwards.
*/
  BYTE_STREAM_SPLIT,
}
/**
* The Parquet version to use when writing
*/
export enum WriterVersion {
  V1,
  V2,
}
/**
* Metadata for a Parquet file.
*/
export class ArrowSchema {
  free(): void;
/**
* Clone this struct in wasm memory.
* @returns {ArrowSchema}
*/
  copy(): ArrowSchema;
}
/**
* Metadata for a column chunk.
*/
export class ColumnChunkMetaData {
  free(): void;
/**
* File where the column chunk is stored.
*
* If not set, assumed to belong to the same file as the metadata.
* This path is relative to the current file.
* @returns {string | undefined}
*/
  filePath(): string | undefined;
/**
* Byte offset in `file_path()`.
* @returns {bigint}
*/
  fileOffset(): bigint;
/**
* @returns {string}
*/
  pathInSchema(): string;
/**
* @returns {boolean}
*/
  statistics_exist(): boolean;
/**
* @returns {any}
*/
  getStatisticsMinValue(): any;
/**
* @returns {any}
*/
  getStatisticsMaxValue(): any;
/**
* @returns {any}
*/
  getStatisticsNullCount(): any;
/**
* Total number of values in this column chunk. Note that this is not necessarily the number
* of rows. E.g. the (nested) array `[[1, 2], [3]]` has 2 rows and 3 values.
* @returns {bigint}
*/
  numValues(): bigint;
/**
* Returns the total compressed data size of this column chunk.
* @returns {bigint}
*/
  compressedSize(): bigint;
/**
* Returns the total uncompressed data size of this column chunk.
* @returns {bigint}
*/
  uncompressedSize(): bigint;
/**
* Returns the offset for the column data.
* @returns {bigint}
*/
  dataPageOffset(): bigint;
/**
* Returns `true` if this column chunk contains a index page, `false` otherwise.
* @returns {boolean}
*/
  hasIndexPage(): boolean;
/**
* Returns the offset for the index page.
* @returns {bigint | undefined}
*/
  indexPageOffset(): bigint | undefined;
/**
* Returns the offset for the dictionary page, if any.
* @returns {bigint | undefined}
*/
  dictionaryPageOffset(): bigint | undefined;
/**
* Returns the number of encodings for this column
* @returns {number}
*/
  numColumnEncodings(): number;
/**
* Returns the offset and length in bytes of the column chunk within the file
* @returns {BigUint64Array}
*/
  byteRange(): BigUint64Array;
}
/**
* Metadata for a Parquet file.
*/
export class FileMetaData {
  free(): void;
/**
* Clone this struct in wasm memory.
* @returns {FileMetaData}
*/
  copy(): FileMetaData;
/**
* Version of this file.
* @returns {number}
*/
  version(): number;
/**
* number of rows in the file.
* @returns {number}
*/
  numRows(): number;
/**
* String message for application that wrote this file.
* @returns {string | undefined}
*/
  createdBy(): string | undefined;
/**
* Number of row groups in the file
* @returns {number}
*/
  numRowGroups(): number;
/**
* Returns a single RowGroupMetaData by index
* @param {number} i
* @returns {RowGroupMetaData}
*/
  rowGroup(i: number): RowGroupMetaData;
/**
* @returns {SchemaDescriptor}
*/
  schema(): SchemaDescriptor;
/**
* @returns {any}
*/
  keyValueMetadata(): any;
/**
* @returns {ArrowSchema}
*/
  arrowSchema(): ArrowSchema;
}
/**
* Metadata for a row group.
*/
export class RowGroupMetaData {
  free(): void;
/**
* Number of rows in this row group.
* @returns {number}
*/
  numRows(): number;
/**
* Number of columns in this row group.
* @returns {number}
*/
  numColumns(): number;
/**
* Returns a single column chunk metadata by index
* @param {number} i
* @returns {ColumnChunkMetaData}
*/
  column(i: number): ColumnChunkMetaData;
/**
* Total byte size of all uncompressed column data in this row group.
* @returns {number}
*/
  totalByteSize(): number;
/**
* Total size of all compressed column data in this row group.
* @returns {number}
*/
  compressedSize(): number;
}
/**
* A schema descriptor. This encapsulates the top-level schemas for all the columns,
* as well as all descriptors for all the primitive columns.
*/
export class SchemaDescriptor {
  free(): void;
/**
* The schemas' name.
* @returns {string}
*/
  name(): string;
/**
* The number of columns in the schema
* @returns {number}
*/
  numColumns(): number;
/**
* The number of fields in the schema
* @returns {number}
*/
  numFields(): number;
}
/**
* Immutable struct to hold writing configuration for `writeParquet2`.
*
* Use {@linkcode WriterPropertiesBuilder} to create a configuration, then call {@linkcode
* WriterPropertiesBuilder.build} to create an instance of `WriterProperties`.
*/
export class WriterProperties {
  free(): void;
}
/**
* Builder to create a writing configuration for `writeParquet2`
*
* Call {@linkcode build} on the finished builder to create an immputable {@linkcode WriterProperties} to pass to `writeParquet2`
*/
export class WriterPropertiesBuilder {
  free(): void;
/**
* Returns default state of the builder.
*/
  constructor();
/**
* Finalizes the configuration and returns immutable writer properties struct.
* @returns {WriterProperties}
*/
  build(): WriterProperties;
/**
* Sets writer version.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setWriterVersion(value: number): WriterPropertiesBuilder;
/**
* Sets encoding for any column.
*
* If dictionary is not enabled, this is treated as a primary encoding for all
* columns. In case when dictionary is enabled for any column, this value is
* considered to be a fallback encoding for that column.
*
* Panics if user tries to set dictionary encoding here, regardless of dictionary
* encoding flag being set.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setEncoding(value: number): WriterPropertiesBuilder;
/**
* Sets compression codec for any column.
* @param {number} value
* @returns {WriterPropertiesBuilder}
*/
  setCompression(value: number): WriterPropertiesBuilder;
/**
* Sets flag to enable/disable statistics for any column.
* @param {boolean} value
* @returns {WriterPropertiesBuilder}
*/
  setStatisticsEnabled(value: boolean): WriterPropertiesBuilder;
}

export type InitInput = RequestInfo | URL | Response | BufferSource | WebAssembly.Module;

export interface InitOutput {
  readonly memory: WebAssembly.Memory;
  readonly __wbg_filemetadata_free: (a: number) => void;
  readonly filemetadata_copy: (a: number) => number;
  readonly filemetadata_version: (a: number) => number;
  readonly filemetadata_numRows: (a: number) => number;
  readonly filemetadata_createdBy: (a: number, b: number) => void;
  readonly filemetadata_numRowGroups: (a: number) => number;
  readonly filemetadata_rowGroup: (a: number, b: number) => number;
  readonly filemetadata_schema: (a: number) => number;
  readonly filemetadata_keyValueMetadata: (a: number, b: number) => void;
  readonly filemetadata_arrowSchema: (a: number, b: number) => void;
  readonly __wbg_rowgroupmetadata_free: (a: number) => void;
  readonly rowgroupmetadata_numRows: (a: number) => number;
  readonly rowgroupmetadata_numColumns: (a: number) => number;
  readonly rowgroupmetadata_column: (a: number, b: number) => number;
  readonly rowgroupmetadata_totalByteSize: (a: number) => number;
  readonly rowgroupmetadata_compressedSize: (a: number) => number;
  readonly __wbg_columnchunkmetadata_free: (a: number) => void;
  readonly columnchunkmetadata_filePath: (a: number, b: number) => void;
  readonly columnchunkmetadata_fileOffset: (a: number, b: number) => void;
  readonly columnchunkmetadata_pathInSchema: (a: number, b: number) => void;
  readonly columnchunkmetadata_statistics_exist: (a: number, b: number) => void;
  readonly columnchunkmetadata_getStatisticsMinValue: (a: number, b: number) => void;
  readonly columnchunkmetadata_getStatisticsMaxValue: (a: number, b: number) => void;
  readonly columnchunkmetadata_getStatisticsNullCount: (a: number, b: number) => void;
  readonly columnchunkmetadata_numValues: (a: number, b: number) => void;
  readonly columnchunkmetadata_compressedSize: (a: number, b: number) => void;
  readonly columnchunkmetadata_uncompressedSize: (a: number, b: number) => void;
  readonly columnchunkmetadata_dataPageOffset: (a: number, b: number) => void;
  readonly columnchunkmetadata_hasIndexPage: (a: number) => number;
  readonly columnchunkmetadata_indexPageOffset: (a: number, b: number) => void;
  readonly columnchunkmetadata_dictionaryPageOffset: (a: number, b: number) => void;
  readonly columnchunkmetadata_numColumnEncodings: (a: number) => number;
  readonly columnchunkmetadata_byteRange: (a: number, b: number) => void;
  readonly __wbg_schemadescriptor_free: (a: number) => void;
  readonly schemadescriptor_name: (a: number, b: number) => void;
  readonly schemadescriptor_numColumns: (a: number) => number;
  readonly schemadescriptor_numFields: (a: number) => number;
  readonly __wbg_writerproperties_free: (a: number) => void;
  readonly __wbg_writerpropertiesbuilder_free: (a: number) => void;
  readonly writerpropertiesbuilder_new: () => number;
  readonly writerpropertiesbuilder_build: (a: number) => number;
  readonly writerpropertiesbuilder_setWriterVersion: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setEncoding: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setCompression: (a: number, b: number) => number;
  readonly writerpropertiesbuilder_setStatisticsEnabled: (a: number, b: number) => number;
  readonly readParquet: (a: number, b: number, c: number) => void;
  readonly readMetadata: (a: number, b: number, c: number) => void;
  readonly readRowGroup: (a: number, b: number, c: number, d: number, e: number) => void;
  readonly readMetadataAsync: (a: number, b: number, c: number) => number;
  readonly readRowGroupAsync: (a: number, b: number, c: number, d: number) => number;
  readonly writeParquet: (a: number, b: number, c: number, d: number) => void;
  readonly __wbg_arrowschema_free: (a: number) => void;
  readonly arrowschema_copy: (a: number) => number;
  readonly ZSTD_endStream: (a: number, b: number) => number;
  readonly ZSTD_compressStream: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompressStream: (a: number, b: number, c: number) => number;
  readonly ZSTD_compress2: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_decompressDCtx: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_isError: (a: number) => number;
  readonly ZSTD_versionNumber: () => number;
  readonly ZSTD_versionString: () => number;
  readonly ZSTD_minCLevel: () => number;
  readonly ZSTD_maxCLevel: () => number;
  readonly ZSTD_getDecompressedSize: (a: number, b: number) => number;
  readonly ZSTD_compressBound: (a: number) => number;
  readonly ZSTD_createCCtx: () => number;
  readonly ZSTD_initCStream: (a: number, b: number) => number;
  readonly ZSTD_CCtx_loadDictionary: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_refCDict: (a: number, b: number) => number;
  readonly ZSTD_CCtx_refPrefix: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_CCtx: (a: number) => number;
  readonly ZSTD_CCtx_reset: (a: number, b: number) => number;
  readonly ZSTD_CCtx_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_setPledgedSrcSize: (a: number, b: number) => number;
  readonly ZSTD_CStreamInSize: () => number;
  readonly ZSTD_CStreamOutSize: () => number;
  readonly ZSTD_freeCCtx: (a: number) => number;
  readonly ZSTD_getErrorName: (a: number) => number;
  readonly ZSTD_createDCtx: () => number;
  readonly ZSTD_initDStream: (a: number) => number;
  readonly ZSTD_DCtx_reset: (a: number, b: number) => number;
  readonly ZSTD_DCtx_loadDictionary: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_refDDict: (a: number, b: number) => number;
  readonly ZSTD_DCtx_refPrefix: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_DStreamInSize: () => number;
  readonly ZSTD_DStreamOutSize: () => number;
  readonly ZSTD_sizeof_DCtx: (a: number) => number;
  readonly ZSTD_freeDCtx: (a: number) => number;
  readonly ZSTD_createCDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_CDict: (a: number) => number;
  readonly ZSTD_getDictID_fromCDict: (a: number) => number;
  readonly ZSTD_freeCDict: (a: number) => number;
  readonly ZSTD_createDDict: (a: number, b: number) => number;
  readonly ZSTD_sizeof_DDict: (a: number) => number;
  readonly ZSTD_getDictID_fromDDict: (a: number) => number;
  readonly ZSTD_freeDDict: (a: number) => number;
  readonly ZSTD_compress_usingCDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_decompress_usingDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_compress_usingDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_decompress_usingDDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_compressCCtx: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_findFrameCompressedSize: (a: number, b: number) => number;
  readonly ZSTD_getFrameContentSize: (a: number, b: number) => number;
  readonly ZSTD_getDictID_fromDict: (a: number, b: number) => number;
  readonly ZSTD_getDictID_fromFrame: (a: number, b: number) => number;
  readonly rust_zstd_wasm_shim_malloc: (a: number) => number;
  readonly rust_zstd_wasm_shim_calloc: (a: number, b: number) => number;
  readonly rust_zstd_wasm_shim_free: (a: number) => void;
  readonly rust_zstd_wasm_shim_memcpy: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memmove: (a: number, b: number, c: number) => number;
  readonly rust_zstd_wasm_shim_memset: (a: number, b: number, c: number) => number;
  readonly ZSTD_createCCtx_advanced: (a: number) => number;
  readonly ZSTD_initStaticCCtx: (a: number, b: number) => number;
  readonly ZSTD_sizeof_CStream: (a: number) => number;
  readonly ZSTD_createCCtxParams: () => number;
  readonly ZSTD_freeCCtxParams: (a: number) => number;
  readonly ZSTD_CCtxParams_reset: (a: number) => number;
  readonly ZSTD_CCtxParams_init: (a: number, b: number) => number;
  readonly ZSTD_CCtxParams_init_advanced: (a: number, b: number) => number;
  readonly ZSTD_checkCParams: (a: number) => number;
  readonly ZSTD_cParam_getBounds: (a: number, b: number) => void;
  readonly ZSTD_CCtxParams_setParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtxParams_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_setParametersUsingCCtxParams: (a: number, b: number) => number;
  readonly ZSTD_CCtx_loadDictionary_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_CCtx_loadDictionary_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_CCtx_refThreadPool: (a: number, b: number) => number;
  readonly ZSTD_CCtx_refPrefix_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_adjustCParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_estimateCCtxSize_usingCCtxParams: (a: number) => number;
  readonly ZSTD_estimateCCtxSize_usingCParams: (a: number) => number;
  readonly ZSTD_estimateCCtxSize: (a: number) => number;
  readonly ZSTD_estimateCStreamSize_usingCCtxParams: (a: number) => number;
  readonly ZSTD_estimateCStreamSize_usingCParams: (a: number) => number;
  readonly ZSTD_estimateCStreamSize: (a: number) => number;
  readonly ZSTD_getFrameProgression: (a: number, b: number) => void;
  readonly ZSTD_toFlushNow: (a: number) => number;
  readonly ZSTD_copyCCtx: (a: number, b: number, c: number) => number;
  readonly ZSTD_generateSequences: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressStream2: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_mergeBlockDelimiters: (a: number, b: number) => number;
  readonly ZSTD_writeSkippableFrame: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressContinue: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_getBlockSize: (a: number) => number;
  readonly ZSTD_compressBlock: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressBegin_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compressBegin_usingDict: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_compressBegin: (a: number, b: number) => number;
  readonly ZSTD_compressEnd: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_compress_advanced: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_compress: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_estimateCDictSize_advanced: (a: number, b: number, c: number) => number;
  readonly ZSTD_estimateCDictSize: (a: number, b: number) => number;
  readonly ZSTD_createCDict_advanced: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_createCDict_advanced2: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_createCDict_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_initStaticCDict: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_compressBegin_usingCDict_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_compressBegin_usingCDict: (a: number, b: number) => number;
  readonly ZSTD_compress_usingCDict_advanced: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_createCStream: () => number;
  readonly ZSTD_createCStream_advanced: (a: number) => number;
  readonly ZSTD_initStaticCStream: (a: number, b: number) => number;
  readonly ZSTD_freeCStream: (a: number) => number;
  readonly ZSTD_resetCStream: (a: number, b: number) => number;
  readonly ZSTD_initCStream_usingCDict_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initCStream_usingCDict: (a: number, b: number) => number;
  readonly ZSTD_initCStream_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_initCStream_usingDict: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initCStream_srcSize: (a: number, b: number, c: number) => number;
  readonly ZSTD_compressStream2_simpleArgs: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number) => number;
  readonly ZSTD_compressSequences: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_flushStream: (a: number, b: number) => number;
  readonly ZSTD_defaultCLevel: () => number;
  readonly ZSTD_getCParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_getParams: (a: number, b: number, c: number, d: number) => void;
  readonly ZSTD_createDDict_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_createDDict_byReference: (a: number, b: number) => number;
  readonly ZSTD_initStaticDDict: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly ZSTD_estimateDDictSize: (a: number, b: number) => number;
  readonly ZSTD_estimateDCtxSize: () => number;
  readonly ZSTD_initStaticDCtx: (a: number, b: number) => number;
  readonly ZSTD_createDCtx_advanced: (a: number) => number;
  readonly ZSTD_copyDCtx: (a: number, b: number) => void;
  readonly ZSTD_isFrame: (a: number, b: number) => number;
  readonly ZSTD_isSkippableFrame: (a: number, b: number) => number;
  readonly ZSTD_frameHeaderSize: (a: number, b: number) => number;
  readonly ZSTD_getFrameHeader_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_getFrameHeader: (a: number, b: number, c: number) => number;
  readonly ZSTD_readSkippableFrame: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_findDecompressedSize: (a: number, b: number) => number;
  readonly ZSTD_decompressBound: (a: number, b: number) => number;
  readonly ZSTD_insertBlock: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompressBegin_usingDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_decompress: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_nextSrcSizeToDecompress: (a: number) => number;
  readonly ZSTD_nextInputType: (a: number) => number;
  readonly ZSTD_decompressContinue: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_decompressBegin: (a: number) => number;
  readonly ZSTD_decompressBegin_usingDDict: (a: number, b: number) => number;
  readonly ZSTD_createDStream: () => number;
  readonly ZSTD_initStaticDStream: (a: number, b: number) => number;
  readonly ZSTD_createDStream_advanced: (a: number) => number;
  readonly ZSTD_freeDStream: (a: number) => number;
  readonly ZSTD_DCtx_loadDictionary_advanced: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly ZSTD_DCtx_loadDictionary_byReference: (a: number, b: number, c: number) => number;
  readonly ZSTD_DCtx_refPrefix_advanced: (a: number, b: number, c: number, d: number) => number;
  readonly ZSTD_initDStream_usingDict: (a: number, b: number, c: number) => number;
  readonly ZSTD_initDStream_usingDDict: (a: number, b: number) => number;
  readonly ZSTD_resetDStream: (a: number) => number;
  readonly ZSTD_DCtx_setMaxWindowSize: (a: number, b: number) => number;
  readonly ZSTD_dParam_getBounds: (a: number, b: number) => void;
  readonly ZSTD_DCtx_setFormat: (a: number, b: number) => number;
  readonly ZSTD_DCtx_getParameter: (a: number, b: number, c: number) => number;
  readonly ZSTD_sizeof_DStream: (a: number) => number;
  readonly ZSTD_decodingBufferSize_min: (a: number, b: number) => number;
  readonly ZSTD_estimateDStreamSize: (a: number) => number;
  readonly ZSTD_estimateDStreamSize_fromFrame: (a: number, b: number) => number;
  readonly ZSTD_decompressStream_simpleArgs: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly ZSTD_decompressBlock: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BrotliDecoderCreateInstance: (a: number, b: number, c: number) => number;
  readonly BrotliDecoderSetParameter: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDecompress: (a: number, b: number, c: number, d: number) => number;
  readonly BrotliDecoderDecompressStream: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly BrotliDecoderDecompressStreaming: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BrotliDecoderDecompressWithReturnInfo: (a: number, b: number, c: number, d: number, e: number) => void;
  readonly BrotliDecoderDecompressPrealloc: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number) => void;
  readonly BrotliDecoderMallocU8: (a: number, b: number) => number;
  readonly BrotliDecoderFreeU8: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderMallocUsize: (a: number, b: number) => number;
  readonly BrotliDecoderFreeUsize: (a: number, b: number, c: number) => void;
  readonly BrotliDecoderDestroyInstance: (a: number) => void;
  readonly BrotliDecoderVersion: () => number;
  readonly CBrotliDecoderErrorString: (a: number) => number;
  readonly BrotliDecoderErrorString: (a: number) => number;
  readonly CBrotliDecoderHasMoreOutput: (a: number) => number;
  readonly BrotliDecoderHasMoreOutput: (a: number) => number;
  readonly CBrotliDecoderTakeOutput: (a: number, b: number) => number;
  readonly BrotliDecoderTakeOutput: (a: number, b: number) => number;
  readonly CBrotliDecoderIsUsed: (a: number) => number;
  readonly BrotliDecoderIsUsed: (a: number) => number;
  readonly CBrotliDecoderIsFinished: (a: number) => number;
  readonly BrotliDecoderIsFinished: (a: number) => number;
  readonly CBrotliDecoderGetErrorCode: (a: number) => number;
  readonly BrotliDecoderGetErrorCode: (a: number) => number;
  readonly CBrotliDecoderGetErrorString: (a: number) => number;
  readonly BrotliDecoderGetErrorString: (a: number) => number;
  readonly BrotliEncoderCompressMulti: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number) => number;
  readonly BrotliEncoderCreateInstance: (a: number, b: number, c: number) => number;
  readonly BrotliEncoderSetParameter: (a: number, b: number, c: number) => number;
  readonly BrotliEncoderDestroyInstance: (a: number) => void;
  readonly BrotliEncoderIsFinished: (a: number) => number;
  readonly BrotliEncoderHasMoreOutput: (a: number) => number;
  readonly BrotliEncoderSetCustomDictionary: (a: number, b: number, c: number) => void;
  readonly BrotliEncoderTakeOutput: (a: number, b: number) => number;
  readonly BrotliEncoderVersion: () => number;
  readonly BrotliEncoderMaxCompressedSize: (a: number) => number;
  readonly BrotliEncoderCompress: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly BrotliEncoderCompressStreaming: (a: number, b: number, c: number, d: number, e: number, f: number) => number;
  readonly BrotliEncoderCompressStream: (a: number, b: number, c: number, d: number, e: number, f: number, g: number) => number;
  readonly BrotliEncoderMallocU8: (a: number, b: number) => number;
  readonly BrotliEncoderFreeU8: (a: number, b: number, c: number) => void;
  readonly BrotliEncoderMallocUsize: (a: number, b: number) => number;
  readonly BrotliEncoderFreeUsize: (a: number, b: number, c: number) => void;
  readonly BroccoliCreateInstance: (a: number) => void;
  readonly BroccoliCreateInstanceWithWindowSize: (a: number, b: number) => void;
  readonly BroccoliDestroyInstance: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number, l: number, m: number, n: number, o: number, p: number, q: number, r: number, s: number, t: number, u: number, v: number, w: number, x: number, y: number, z: number, a1: number, b1: number, c1: number, d1: number, e1: number, f1: number, g1: number, h1: number, i1: number, j1: number, k1: number, l1: number, m1: number, n1: number, o1: number, p1: number, q1: number, r1: number, s1: number, t1: number, u1: number, v1: number, w1: number, x1: number, y1: number, z1: number, a2: number, b2: number, c2: number, d2: number, e2: number, f2: number, g2: number, h2: number, i2: number, j2: number, k2: number, l2: number, m2: number, n2: number, o2: number, p2: number, q2: number, r2: number, s2: number, t2: number, u2: number, v2: number, w2: number, x2: number, y2: number, z2: number, a3: number, b3: number, c3: number, d3: number, e3: number, f3: number, g3: number, h3: number, i3: number, j3: number, k3: number, l3: number, m3: number, n3: number, o3: number, p3: number, q3: number, r3: number, s3: number, t3: number, u3: number, v3: number, w3: number, x3: number, y3: number, z3: number, a4: number, b4: number, c4: number, d4: number, e4: number, f4: number, g4: number, h4: number, i4: number, j4: number, k4: number, l4: number, m4: number, n4: number, o4: number, p4: number, q4: number) => void;
  readonly BroccoliNewBrotliFile: (a: number) => void;
  readonly BroccoliConcatStream: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BroccoliConcatStreaming: (a: number, b: number, c: number, d: number, e: number) => number;
  readonly BroccoliConcatFinish: (a: number, b: number, c: number) => number;
  readonly BroccoliConcatFinished: (a: number, b: number, c: number) => number;
  readonly BrotliEncoderMaxCompressedSizeMulti: (a: number, b: number) => number;
  readonly BrotliEncoderCreateWorkPool: (a: number, b: number, c: number, d: number) => number;
  readonly BrotliEncoderDestroyWorkPool: (a: number) => void;
  readonly BrotliEncoderCompressWorkPool: (a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number, l: number) => number;
  readonly __wbindgen_malloc: (a: number) => number;
  readonly __wbindgen_realloc: (a: number, b: number, c: number) => number;
  readonly __wbindgen_export_2: WebAssembly.Table;
  readonly _dyn_core__ops__function__FnMut__A____Output___R_as_wasm_bindgen__closure__WasmClosure___describe__invoke__h1ab7ddc3308ee299: (a: number, b: number, c: number) => void;
  readonly __wbindgen_add_to_stack_pointer: (a: number) => number;
  readonly __wbindgen_free: (a: number, b: number) => void;
  readonly __wbindgen_exn_store: (a: number) => void;
  readonly wasm_bindgen__convert__closures__invoke2_mut__hfe0082abbc39a11f: (a: number, b: number, c: number, d: number) => void;
}

/**
* Synchronously compiles the given `bytes` and instantiates the WebAssembly module.
*
* @param {BufferSource} bytes
*
* @returns {InitOutput}
*/
export function initSync(bytes: BufferSource): InitOutput;

/**
* If `module_or_path` is {RequestInfo} or {URL}, makes a request and
* for everything else, calls `WebAssembly.instantiate` directly.
*
* @param {InitInput | Promise<InitInput>} module_or_path
*
* @returns {Promise<InitOutput>}
*/
export default function init (module_or_path?: InitInput | Promise<InitInput>): Promise<InitOutput>;
